/*
  Motor control library for US droid mini robot

  Created by Steve Nishiarai 18/Jan/2019
  Copyright (c) 2019 Parawind Lab.  All right reserved.
*/

#ifndef MBmotor_h
#define MBmotor_h

// library interface description
class MBmotor
{
  // user-accessible "public" interface
  public:
    MBmotor(int MCLpinI, int MCRpinI, int MSLpinI, int MSRpinI, int MREFpinI);
    void begin(byte, byte, byte, byte, byte, byte, byte, byte); //(Right motor trim factor for proceeding forward,
    //Left motor trim factor for proceeding forward,
    //Right motor trim factor for turning left,
    //Left motor trim factor for turning right,
    //Minimum speed BEMF value,
    //Nominal speed BEMF value,
    //Acceleration time,
    //BEMF feedback gain factor)
    void ProceedForward(byte, byte); //(Left motor steering factor, Right motor steering factor)
    void RotateRight();
    void RotateLeft();
    void SlowStop();
    void FastStop();
    void InstantStop();
    void WaitForStop();
    boolean CheckStop();
    void InitLowBatt();
    unsigned int ReadLowBatt();
    unsigned int ReadBatt();

  // library-accessible "private" interface
  private:
    unsigned int Trim( byte, byte, unsigned int);
};

#endif
